@@ -10,9 +10,7 @@ use crate::print_perf;
 mod action;
 pub use action::*;
 
-#[cfg(feature = "widgets")]
 mod widgets;
-#[cfg(feature = "widgets")]
 pub use widgets::*;
 
 /// A global Store
@@ -395,6 +393,7 @@ macro_rules! check_internal {
         $object:ident
     ) => {
         unsafe {
+            use glib::ObjectExt;
             if let Some(internal) = $object.data::<bool>("internal") {
                 if *internal.as_ref() {
                     return;
