@@ -12,7 +12,7 @@ macro_rules! print_perf {
             let t0 = std::time::Instant::now();
             $expr;
             let d = std::time::Instant::now().duration_since(t0);
-            println!("[gstore] [{:06} μs]: {}", d.as_micros(), $message);
+            info!("[gstore] [{:06} μs]: {}", d.as_micros(), $message);
         } else {
             $expr;
         }
